@@ -18,10 +18,6 @@
 
 #include "camel-mapi-settings.h"
 
-#define CAMEL_MAPI_SETTINGS_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), CAMEL_TYPE_MAPI_SETTINGS, CamelMapiSettingsPrivate))
-
 struct _CamelMapiSettingsPrivate {
 	GMutex property_lock;
 
@@ -57,6 +53,7 @@ G_DEFINE_TYPE_WITH_CODE (
 	CamelMapiSettings,
 	camel_mapi_settings,
 	CAMEL_TYPE_OFFLINE_SETTINGS,
+	G_ADD_PRIVATE (CamelMapiSettings)
 	G_IMPLEMENT_INTERFACE (
 		CAMEL_TYPE_NETWORK_SETTINGS, NULL))
 
@@ -255,15 +252,13 @@ mapi_settings_get_property (GObject *object,
 static void
 mapi_settings_finalize (GObject *object)
 {
-	CamelMapiSettingsPrivate *priv;
+	CamelMapiSettings *mapi_settings = CAMEL_MAPI_SETTINGS (object);
 
-	priv = CAMEL_MAPI_SETTINGS_GET_PRIVATE (object);
+	g_mutex_clear (&mapi_settings->priv->property_lock);
 
-	g_mutex_clear (&priv->property_lock);
-
-	g_free (priv->domain);
-	g_free (priv->profile);
-	g_free (priv->realm);
+	g_free (mapi_settings->priv->domain);
+	g_free (mapi_settings->priv->profile);
+	g_free (mapi_settings->priv->realm);
 
 	/* Chain up to parent's finalize() method. */
 	G_OBJECT_CLASS (camel_mapi_settings_parent_class)->finalize (object);
@@ -274,8 +269,6 @@ camel_mapi_settings_class_init (CamelMapiSettingsClass *class)
 {
 	GObjectClass *object_class;
 
-	g_type_class_add_private (class, sizeof (CamelMapiSettingsPrivate));
-
 	object_class = G_OBJECT_CLASS (class);
 	object_class->set_property = mapi_settings_set_property;
 	object_class->get_property = mapi_settings_get_property;
@@ -411,7 +404,7 @@ camel_mapi_settings_class_init (CamelMapiSettingsClass *class)
 static void
 camel_mapi_settings_init (CamelMapiSettings *settings)
 {
-	settings->priv = CAMEL_MAPI_SETTINGS_GET_PRIVATE (settings);
+	settings->priv = camel_mapi_settings_get_instance_private (settings);
 	g_mutex_init (&settings->priv->property_lock);
 }
 
